@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine.pm 7182 2007-05-14T05:16:50.483550Z lestrrat  $
+# $Id: /local/gungho/lib/Gungho/Engine.pm 11679 2007-05-28T07:05:33.711727Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -45,21 +45,23 @@ sub handle_dns_response
         }
     }
 
-    $self->_http_error(500, "Failed to resolve host " . $request->uri->host, $request),
+    $c->handle_response($request, $self->_http_error(500, "Failed to resolve host " . $request->uri->host, $request)),
 }
 
 sub _address_is_private
 {
     my ($self, $address) = @_;
 
-    if ($address =~ /^$RE{net}{IPv4}$/) {
+    if ($address eq '127.0.0.1') {
+        return 1;
+    } elsif ($address =~ /^$RE{net}{IPv4}$/) {
         my ($o1, $o2, $o3, $o4) = ($2, $3, $4, $5);
 
         if ($o1 eq '10') {
             return 1;
         } elsif ($o1 eq '172') {
             return $o2 >= 16 && $o2 <= 31
-        } elsif ($o1 eq '192' && $o2 eq '160') {
+        } elsif ($o1 eq '192' && $o2 eq '168') {
             return 1;
         }
     }
@@ -112,12 +114,12 @@ Gungho::Engine - Base Class For Gungho Engine
 
 =head1 METHODS
 
-=head2 run()
-
 =head2 handle_dns_response()
 
 Handles the response from DNS lookups.
 
+=head2 run()
+
 Starts the engine. The exact behavior differs between each engine
 
 =cut
