@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Handler/Null.pm 3234 2007-10-13T15:12:58.068532Z lestrrat  $
+# $Id: /local/gungho/lib/Gungho/Handler/Null.pm 7199 2007-05-16T01:24:11.741951Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -15,7 +15,8 @@ sub handle_response
     my $req  = shift;
     my $res  = shift;
 
-    $c->log->info($req->uri . " responded with code " . $res->code);
+    $c->log->info($req->uri . " responded with code " . $res->code)
+        if $c->log->is_info;
     $self->next::method($c, $res);
 }
 
